@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 
-import base64
 
 # Copyright 2016-2017 Nitor Creations Oy
 #
@@ -15,7 +14,8 @@ import base64
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from builtins import str
+
+import base64
 
 from botocore.exceptions import ClientError
 from threadlocal_aws.clients import ecr
@@ -37,19 +37,10 @@ def ensure_repo(name):
     token_resp = ecr().get_authorization_token(registryIds=[repo["registryId"]])
     if "authorizationData" in token_resp:
         auth_data = token_resp["authorizationData"][0]
-        full_token = (
-            base64.b64decode(auth_data["authorizationToken"]).decode("utf-8").split(":")
-        )
+        full_token = base64.b64decode(auth_data["authorizationToken"]).decode("utf-8").split(":")
         user = full_token[0]
         token = full_token[1]
-        print(
-            "docker login -u "
-            + user
-            + " -p "
-            + token
-            + " "
-            + auth_data["proxyEndpoint"]
-        )
+        print("docker login -u " + user + " -p " + token + " " + auth_data["proxyEndpoint"])
 
 
 def repo_uri(name):
