@@ -1,4 +1,3 @@
-from builtins import object
 from locale import getpreferredencoding
 from os import devnull, environ, linesep
 from re import sub
@@ -10,7 +9,7 @@ from tempfile import mkdtemp
 SYS_ENCODING = getpreferredencoding()
 
 
-class Git(object):
+class Git:
     def __init__(self):
         self.entered = 0
         self.export_directories = {}
@@ -52,7 +51,7 @@ class Git(object):
         for dir in list(self.export_directories.values()):
             try:
                 rmtree(dir)
-            except:
+            except Exception:
                 # Best effport deleting only - not fatal
                 pass
 
@@ -65,9 +64,7 @@ class Git(object):
             if not exported:
                 export_branch = self._resolve_branch(branch)
                 if not export_branch:
-                    raise CheckoutException(
-                        "Failed to resolve branch " + branch + " for export"
-                    )
+                    raise CheckoutException("Failed to resolve branch " + branch + " for export")
                 proc = Popen(
                     ["git", "archive", "--format", "tar", export_branch],
                     stdout=PIPE,
@@ -95,9 +92,7 @@ class Git(object):
 
     def get_branches(self):
         if not self.branches:
-            proc = Popen(
-                ["git", "branch", "-a"], stdout=PIPE, stderr=open(devnull, "w")
-            )
+            proc = Popen(["git", "branch", "-a"], stdout=PIPE, stderr=open(devnull, "w"))
             output, _ = proc.communicate()
             for line in output.decode(SYS_ENCODING).split(linesep):
                 if "detached" in line or "(no branch)" in line:
