@@ -50,9 +50,9 @@ usage() {
   echo "                  you would give blobstore" >&2
   echo "" >&2
   echo "optional arguments:" >&2
-  echo "  -d, --dryrun  dry-run - do only parameter expansion and template pre-processing and azure cli what-if operation"  >&2
-  echo "  -v, --verbose verbose - verbose output from azure cli"  >&2
-  echo "  -h, --help    show this help message and exit"  >&2
+  echo "  -d, --dryrun  dry-run - do only parameter expansion and template pre-processing and azure cli what-if operation" >&2
+  echo "  -v, --verbose verbose - verbose output from azure cli" >&2
+  echo "  -h, --help    show this help message and exit" >&2
   if "$@"; then
     echo "" >&2
     echo "$@" >&2
@@ -71,16 +71,18 @@ while [ "$1" = "-d" -o "$1" = "--dryrun" -o "$1" = "-v" -o "$1" = "--verbose" ];
     shift
   fi
 done
-die () {
+die() {
   set +x
   echo "$1" >&2
   usage
 }
 set -xe
 
-component="$1" ; shift
+component="$1"
+shift
 [ "${component}" ] || die "You must give the component name as argument"
-azure="$1"; shift
+azure="$1"
+shift
 [ "${azure}" ] || die "You must give the azure name as argument"
 
 TSTAMP=$(date +%Y%m%d%H%M%S)
@@ -155,7 +157,7 @@ fi
 
 set -e
 az $VERBOSE deployment $SCOPE_COMMAND create \
-  --name $DEPLOYMENT_NAME  \
+  --name $DEPLOYMENT_NAME \
   $GROUP_ARGS \
   $WHATIF_ARG \
   --template-file azuredeploy.$TEMPLATE_TYPE \
