@@ -48,9 +48,9 @@ usage() {
   echo "                  you would give blobstore" >&2
   echo "" >&2
   echo "optional arguments:" >&2
-  echo "  -d, --dryrun  dry-run - do only parameter expansion and template pre-processing and azure cli what-if operation"  >&2
-  echo "  -v, --verbose verbose - verbose output from azure cli"  >&2
-  echo "  -h, --help    show this help message and exit"  >&2
+  echo "  -d, --dryrun  dry-run - do only parameter expansion and template pre-processing and azure cli what-if operation" >&2
+  echo "  -v, --verbose verbose - verbose output from azure cli" >&2
+  echo "  -h, --help    show this help message and exit" >&2
   if "$@"; then
     echo "" >&2
     echo "$@" >&2
@@ -69,16 +69,18 @@ while [ "$1" = "-d" -o "$1" = "--dryrun" -o "$1" = "-v" -o "$1" = "--verbose" ];
     shift
   fi
 done
-die () {
+die() {
   set +x
   echo "$1" >&2
   usage
 }
 set -xe
 
-component="$1" ; shift
+component="$1"
+shift
 [ "${component}" ] || die "You must give the component name as argument"
-azure="$1"; shift
+azure="$1"
+shift
 [ "${azure}" ] || die "You must give the azure name as argument"
 
 eval "$(ndt load-parameters "$component" -a "$azure" -e -r)"
