@@ -19,9 +19,7 @@ def get_lpentry(search_term):
     item_data = json.loads(item)
     if len(item_data) > 0:
         # find exact match for search term
-        item = [
-            item for item in item_data if item["name"].lower() == search_term.lower()
-        ][0]
+        item = [item for item in item_data if item["name"].lower() == search_term.lower()][0]
         ret = LpEntry(item)
         _LP_CACHE[search_term] = ret
         return ret
